@@ -359,7 +359,7 @@ class CRM_Core_BAO_CustomGroup extends CRM_Core_DAO_CustomGroup implements \Civi
     $transaction->commit();
 
     // reset the cache
-    CRM_Utils_System::flushCache();
+    Civi::rebuild(['system' => TRUE])->execute();
 
     CRM_Utils_Hook::post($op, 'CustomGroup', $group->id, $group);
 
@@ -403,7 +403,7 @@ class CRM_Core_BAO_CustomGroup extends CRM_Core_DAO_CustomGroup implements \Civi
     // reset the cache
     Civi::cache('fields')->flush();
     // reset ACL and system caches.
-    CRM_Core_BAO_Cache::resetCaches();
+    Civi::rebuild(['system' => TRUE])->execute();
 
     if (!$is_active) {
       CRM_Core_BAO_UFField::setUFFieldStatus($id, $is_active);
@@ -945,135 +945,6 @@ class CRM_Core_BAO_CustomGroup extends CRM_Core_DAO_CustomGroup implements \Civi
     return $groupTree;
   }
 
-  /**
-   * @deprecated since 5.71, will be removed around 5.85
-   */
-  public static function &getActiveGroups($entityType, $path, $cidToken = '%%cid%%') {
-    // for Group's
-    $customGroupDAO = new CRM_Core_DAO_CustomGroup();
-
-    // get 'Tab' and 'Tab with table' groups
-    $customGroupDAO->whereAdd("style IN ('Tab', 'Tab with table')");
-    $customGroupDAO->whereAdd("is_active = 1");
-
-    // Emits a noisy deprecation notice
-    self::_addWhereAdd($customGroupDAO, $entityType, $cidToken);
-
-    $groups = [];
-
-    $permissionClause = CRM_Core_Permission::customGroupClause(CRM_Core_Permission::VIEW, NULL, TRUE);
-    $customGroupDAO->whereAdd($permissionClause);
-
-    // order by weight
-    $customGroupDAO->orderBy('weight');
-    $customGroupDAO->find();
-
-    // process each group with menu tab
-    while ($customGroupDAO->fetch()) {
-      $group = [];
-      $group['id'] = $customGroupDAO->id;
-      $group['path'] = $path;
-      $group['title'] = "$customGroupDAO->title";
-      $group['query'] = "reset=1&gid={$customGroupDAO->id}&cid={$cidToken}";
-      $group['extra'] = ['gid' => $customGroupDAO->id];
-      $group['table_name'] = $customGroupDAO->table_name;
-      $group['is_multiple'] = $customGroupDAO->is_multiple;
-      $group['icon'] = $customGroupDAO->icon;
-      $groups[] = $group;
-    }
-
-    return $groups;
-  }
-
-  /**
-   * Unused function.
-   * @deprecated since 5.71 will be removed around 5.85
-   */
-  public static function getTableNameByEntityName($entityType) {
-    CRM_Core_Error::deprecatedFunctionWarning('CoreUtil::getTableName');
-    switch ($entityType) {
-      case 'Contact':
-      case 'Individual':
-      case 'Household':
-      case 'Organization':
-        return 'civicrm_contact';
-
-      default:
-        return CRM_Core_DAO_AllCoreTables::getTableForEntityName($entityType);
-    }
-  }
-
-  /**
-   * @deprecated since 5.71 will be removed around 5.85
-   *
-   * @param string $entityType
-   *
-   * @return CRM_Core_DAO_CustomGroup
-   */
-  public static function getAllCustomGroupsByBaseEntity($entityType) {
-    $customGroupDAO = new CRM_Core_DAO_CustomGroup();
-    // Emits a noisy deprecation notice
-    self::_addWhereAdd($customGroupDAO, $entityType, NULL, TRUE);
-    return $customGroupDAO;
-  }
-
-  /**
-   * @deprecated since 5.71 will be removed around 5.85
-   */
-  private static function _addWhereAdd(&$customGroupDAO, $entityType, $entityID = NULL, $allSubtypes = FALSE) {
-    CRM_Core_Error::deprecatedFunctionWarning('CRM_Core_BAO_CustomGroup::getAll');
-    $addSubtypeClause = FALSE;
-    // This function isn't really accessible with user data but since the string
-    // is not passed as a param to the query CRM_Core_DAO::escapeString seems like a harmless
-    // precaution.
-    $entityType = CRM_Core_DAO::escapeString($entityType);
-
-    switch ($entityType) {
-      case 'Contact':
-        // if contact, get all related to contact
-        $extendList = "'Contact','Individual','Household','Organization'";
-        $customGroupDAO->whereAdd("extends IN ( $extendList )");
-        if (!$allSubtypes) {
-          $addSubtypeClause = TRUE;
-        }
-        break;
-
-      case 'Individual':
-      case 'Household':
-      case 'Organization':
-        // is I/H/O then get I/H/O and contact
-        $extendList = "'Contact','$entityType'";
-        $customGroupDAO->whereAdd("extends IN ( $extendList )");
-        if (!$allSubtypes) {
-          $addSubtypeClause = TRUE;
-        }
-        break;
-
-      default:
-        $customGroupDAO->whereAdd("extends IN ('$entityType')");
-        break;
-    }
-
-    if ($addSubtypeClause) {
-      $csType = is_numeric($entityID) ? CRM_Contact_BAO_Contact::getContactSubType($entityID) : FALSE;
-
-      if (!empty($csType)) {
-        $subtypeClause = [];
-        foreach ($csType as $subtype) {
-          $subtype = CRM_Core_DAO::VALUE_SEPARATOR . $subtype .
-            CRM_Core_DAO::VALUE_SEPARATOR;
-          $subtypeClause[] = "extends_entity_column_value LIKE '%{$subtype}%'";
-        }
-        $subtypeClause[] = "extends_entity_column_value IS NULL";
-        $customGroupDAO->whereAdd("( " . implode(' OR ', $subtypeClause) .
-          " )");
-      }
-      else {
-        $customGroupDAO->whereAdd("extends_entity_column_value IS NULL");
-      }
-    }
-  }
-
   /**
    * Delete the Custom Group.
    *
@@ -2188,7 +2059,7 @@ class CRM_Core_BAO_CustomGroup extends CRM_Core_DAO_CustomGroup implements \Civi
     $ogId = CRM_Core_DAO::getFieldValue('CRM_Core_DAO_OptionGroup', 'cg_extend_objects', 'id', 'name');
     $ogValues = CRM_Core_BAO_OptionValue::getOptionValuesArray($ogId);
     foreach ($ogValues as $ogValue) {
-      if ($ogValue['is_active']) {
+      if ($ogValue['is_active'] && \Civi\Schema\EntityRepository::tableExists($ogValue['name'])) {
         $options[$ogValue['value']] = [
           'id' => $ogValue['value'],
           'label' => $ogValue['label'],
