@@ -87,12 +87,15 @@ class CRM_Core_BAO_CustomValueTable {
               break;
 
             case 'File':
+              if (!empty($field['id'])) {
+                self::deleteFile($field);
+              }
               if (!$field['file_id']) {
                 $value = 'null';
                 break;
               }
               $value = $field['file_id'];
-              $type = 'String';
+              $type = 'Integer';
               break;
 
             case 'Date':
@@ -385,24 +388,16 @@ class CRM_Core_BAO_CustomValueTable {
       // adding this here since an empty contact id could have serious repurcussions
       // like looping forever
       throw new CRM_Core_Exception('Please file an issue with the backtrace');
-      return NULL;
     }
 
-    $cond = [];
+    $cond = ['is_active' => TRUE];
     if ($entityType) {
-      $cond[] = "cg.extends IN ( '$entityType' )";
+      $cond['extends'] = $entityType;
     }
-    if ($fieldIDs &&
-      is_array($fieldIDs)
-    ) {
-      $fieldIDList = implode(',', $fieldIDs);
-      $cond[] = "cf.id IN ( $fieldIDList )";
+    // If no entity or field ids given, assume "Contact"
+    elseif (empty($fieldIDs)) {
+      $cond['extends'] = 'Contact';
     }
-    if (empty($cond)) {
-      $contactTypes = array_merge(['Contact'], CRM_Contact_BAO_ContactType::basicTypes(TRUE));
-      $cond[] = "cg.extends IN ( '" . implode("', '", $contactTypes) . "' )";
-    }
-    $cond = implode(' AND ', $cond);
 
     $limit = $orderBy = '';
     if (!empty($DTparams['rowCount']) && $DTparams['rowCount'] > 0) {
@@ -413,33 +408,23 @@ class CRM_Core_BAO_CustomValueTable {
     }
 
     // First find all the fields that extend this type of entity.
-    $query = "
-SELECT cg.table_name,
-       cg.id as groupID,
-       cg.is_multiple,
-       cf.column_name,
-       cf.id as fieldID,
-       cf.data_type as fieldDataType
-FROM   civicrm_custom_group cg,
-       civicrm_custom_field cf
-WHERE  cf.custom_group_id = cg.id
-AND    cg.is_active = 1
-AND    cf.is_active = 1
-AND    $cond
-";
-    $dao = CRM_Core_DAO::executeQuery($query);
-
     $select = $fields = $isMultiple = [];
 
-    while ($dao->fetch()) {
-      if (!array_key_exists($dao->table_name, $select)) {
-        $fields[$dao->table_name] = [];
-        $select[$dao->table_name] = [];
+    $customGroups = CRM_Core_BAO_CustomGroup::getAll($cond);
+    foreach ($customGroups as $customGroup) {
+      foreach ($customGroup['fields'] as $customField) {
+        if ($fieldIDs && !in_array($customField['id'], $fieldIDs)) {
+          continue;
+        }
+        if (!array_key_exists($customGroup['table_name'], $select)) {
+          $fields[$customGroup['table_name']] = [];
+          $select[$customGroup['table_name']] = [];
+        }
+        $fields[$customGroup['table_name']][] = $customField['id'];
+        $select[$customGroup['table_name']][] = "`{$customField['column_name']}` AS custom_{$customField['id']}";
+        $isMultiple[$customGroup['table_name']] = $customGroup['is_multiple'];
+        $file[$customGroup['table_name']][$customField['id']] = $customField['data_type'];
       }
-      $fields[$dao->table_name][] = $dao->fieldID;
-      $select[$dao->table_name][] = "{$dao->column_name} AS custom_{$dao->fieldID}";
-      $isMultiple[$dao->table_name] = (bool) $dao->is_multiple;
-      $file[$dao->table_name][$dao->fieldID] = $dao->fieldDataType;
     }
 
     $result = $sortedResult = [];
@@ -701,4 +686,23 @@ AND    $cond
     }
   }
 
+  /**
+   * Delete orphaned files from disk when updating custom file fields
+   */
+  private static function deleteFile(array $field) {
+    $sql = CRM_Utils_SQL_Select::from($field['table_name'])
+      ->select($field['column_name'])
+      ->where("id = #id", ['#id' => $field['id']])
+      ->toSQL();
+    $fileId = CRM_Core_DAO::singleValueQuery($sql);
+    if ($fileId && $fileId != ($field['file_id'] ?? NULL)) {
+      $refCount = \Civi\Api4\Utils\CoreUtil::getRefCountTotal('File', $fileId);
+      if ($refCount <= 1) {
+        \Civi\Api4\File::delete(FALSE)
+          ->addWhere('id', '=', $fileId)
+          ->execute();
+      }
+    }
+  }
+
 }
