@@ -236,7 +236,7 @@ class CRM_Extension_Manager {
       // It might be useful to reset the container, but (given dev/core#3686) that's not likely to do much.
       // \Civi::reset();
       // \CRM_Core_Config::singleton(TRUE, TRUE);
-      CRM_Core_Invoke::rebuildMenuAndCaches(TRUE);
+      Civi::rebuild(['*' => TRUE, 'sessions' => FALSE])->execute();
     }
 
     return $tgtPath;
@@ -327,7 +327,7 @@ class CRM_Extension_Manager {
     if (!CRM_Core_Config::isUpgradeMode()) {
       \Civi::reset();
       \CRM_Core_Config::singleton(TRUE, TRUE);
-      CRM_Core_Invoke::rebuildMenuAndCaches(TRUE);
+      Civi::rebuild(['*' => TRUE, 'sessions' => FALSE])->execute();
 
       $schema = new CRM_Logging_Schema();
       $schema->fixSchemaDifferences();
@@ -447,7 +447,7 @@ class CRM_Extension_Manager {
     $this->mapper->refresh();
     \Civi::reset();
     \CRM_Core_Config::singleton(TRUE, TRUE);
-    CRM_Core_Invoke::rebuildMenuAndCaches(TRUE);
+    Civi::rebuild(['*' => TRUE, 'sessions' => FALSE])->execute();
 
     $this->popProcess($keys);
   }
@@ -513,7 +513,7 @@ class CRM_Extension_Manager {
     $this->mapper->refresh();
     // At the analogous step of `install()` or `disable()`, it would reset the container.
     // But here, the extension goes from "disabled=>uninstall". All we really need is to reconcile mgd's.
-    CRM_Core_Invoke::rebuildMenuAndCaches(TRUE);
+    Civi::rebuild(['*' => TRUE, 'sessions' => FALSE])->execute();
     $this->popProcess($keys);
   }
 
@@ -730,7 +730,6 @@ class CRM_Extension_Manager {
     if ($dao->find(TRUE)) {
       try {
         CRM_Core_BAO_Extension::deleteRecord(['id' => $dao->id]);
-        CRM_Core_Session::setStatus(ts('Selected option value has been deleted.'), ts('Deleted'), 'success');
       }
       catch (CRM_Core_Exception $e) {
         throw new CRM_Extension_Exception("Failed to remove extension entry $dao->id");
