@@ -351,13 +351,6 @@ class CRM_Financial_BAO_Payment {
     if (!empty($participantRecords)) {
       $entities['participant'] = $participantRecords[0]['api.Participant.get']['values'][0];
       $entities['event'] = civicrm_api3('Event', 'getsingle', ['id' => $entities['participant']['event_id']]);
-      if (!empty($entities['event']['is_show_location'])) {
-        $locationParams = [
-          'entity_id' => $entities['event']['id'],
-          'entity_table' => 'civicrm_event',
-        ];
-        $entities['location'] = CRM_Core_BAO_Location::getValues($locationParams, TRUE);
-      }
     }
 
     return $entities;
@@ -401,9 +394,7 @@ class CRM_Financial_BAO_Payment {
       'paymentAmount' => $entities['payment']['total_amount'],
       'checkNumber' => $entities['payment']['check_number'] ?? NULL,
       'receive_date' => $entities['payment']['trxn_date'],
-      'paidBy' => CRM_Core_PseudoConstant::getLabel('CRM_Core_BAO_FinancialTrxn', 'payment_instrument_id', $entities['payment']['payment_instrument_id']),
       'isShowLocation' => (!empty($entities['event']) ? $entities['event']['is_show_location'] : FALSE),
-      'location' => $entities['location'] ?? NULL,
       'event' => $entities['event'] ?? NULL,
       'component' => (!empty($entities['event']) ? 'event' : 'contribution'),
       'isRefund' => $entities['payment']['total_amount'] < 0,
@@ -412,58 +403,7 @@ class CRM_Financial_BAO_Payment {
       'paymentsComplete' => ($entities['payment']['balance'] == 0),
     ];
 
-    return self::filterUntestedTemplateVariables($templateVariables);
-  }
-
-  /**
-   * Filter out any untested variables.
-   *
-   * This just serves to highlight if any variables are added without a unit test also being added.
-   *
-   * (if hit then add a unit test for the param & add to this array).
-   *
-   * @param array $params
-   *
-   * @return array
-   */
-  public static function filterUntestedTemplateVariables($params) {
-    $testedTemplateVariables = [
-      'contactDisplayName',
-      'totalAmount',
-      'currency',
-      'amountOwed',
-      'paymentAmount',
-      'event',
-      'component',
-      'checkNumber',
-      'receive_date',
-      'paidBy',
-      'isShowLocation',
-      'location',
-      'isRefund',
-      'refundAmount',
-      'totalPaid',
-      'paymentsComplete',
-      'emailGreeting',
-    ];
-    // These are assigned by the payment form - they still 'get through' from the
-    // form for now without being in here but we should ideally load
-    // and assign. Note we should update the tpl to use {if $billingName}
-    // and ditch contributeMode - although it might need to be deprecated rather than removed.
-    $todoParams = [
-      'billingName',
-      'address',
-      'credit_card_type',
-      'credit_card_number',
-      'credit_card_exp_date',
-    ];
-    $filteredParams = [];
-    foreach ($testedTemplateVariables as $templateVariable) {
-      // This will cause an a-notice if any are NOT set - by design. Ensuring
-      // they are set prevents leakage.
-      $filteredParams[$templateVariable] = $params[$templateVariable];
-    }
-    return $filteredParams;
+    return $templateVariables;
   }
 
   /**
