@@ -25,13 +25,12 @@ use GuzzleHttp\Psr7\Response;
  * FIXME: This is a massive and random collection that could be split into smaller services
  *
  * @method static array getCMSPermissionsUrlParams() Return the CMS-specific url for its permissions page.
- * @method static mixed permissionDenied() Show access denied screen.
  * @method static string getContentTemplate(int|string $print = 0) Get the template path to render whole content.
  * @method static mixed logout() Log out the current user.
  * @method static mixed updateCategories() Clear CMS caches related to the user registration/profile forms.
  * @method static void appendBreadCrumb(array $breadCrumbs) Append an additional breadcrumb link to the existing breadcrumbs.
  * @method static void resetBreadCrumb() Reset an additional breadcrumb tag to the existing breadcrumb.
- * @method static void addHTMLHead(string $head) Append a string to the head of the HTML file.
+ * @method static void addHTMLHead(string $head) Append a string to the head of the HTML file. Note: this is only used in Drupal/Backdrop/Joomla and is deprecated in Wordpress/Standalone
  * @method static string postURL(int $action) Determine the post URL for a form.
  * @method static string|null getUFLocale() Get the locale of the CMS.
  * @method static bool setUFLocale(string $civicrm_language) Set the locale of the CMS.
@@ -66,6 +65,23 @@ class CRM_Utils_System {
     return call_user_func_array([$userSystem, $name], $arguments);
   }
 
+  /**
+   * Respond that permission has been denied.
+   *
+   * @return never
+   *   NOTE: The keyword "never" introduced in PHP 8.1+.
+   *   This is a soft docblock, so we can use it anyway.
+   * @throws \CRM_Core_Exception
+   */
+  public static function permissionDenied() {
+    $userSystem = CRM_Core_Config::singleton()->userSystem;
+    $userSystem->permissionDenied();
+    // The UF-drivers might emit an exception, send a redirect, or print a message.
+    // They sometimes terminate - but not always. Let's ensure that the
+    // termination is consistent.
+    return CRM_Utils_System::civiExit();
+  }
+
   /**
    * Compose a new URL string from the current URL string.
    *
@@ -482,9 +498,9 @@ class CRM_Utils_System {
    *   Page title (if different) - may include html
    */
   public static function setTitle($title, $pageTitle = NULL) {
-    self::$title = $title;
+    self::$title = $title = strip_tags($title ?: '');
     $config = CRM_Core_Config::singleton();
-    return $config->userSystem->setTitle(CRM_Utils_String::purifyHtml($title), CRM_Utils_String::purifyHtml($pageTitle));
+    return $config->userSystem->setTitle($title, CRM_Utils_String::purifyHtml($pageTitle));
   }
 
   /**
@@ -1202,7 +1218,11 @@ class CRM_Utils_System {
    * @return void
    */
   public static function setNoRobotsFlag(): void {
-    CRM_Utils_System::addHTMLHead('<META NAME="ROBOTS" CONTENT="NOINDEX, NOFOLLOW">');
+    $region = CRM_Core_Region::instance('html-header', TRUE);
+    $region->add([
+      'type' => 'markup',
+      'markup' => '<META NAME="ROBOTS" CONTENT="NOINDEX, NOFOLLOW">',
+    ]);
   }
 
   /**
