@@ -1145,7 +1145,11 @@ AND    u.status = 1
    * CMS's drupal views expectations, if any.
    */
   public function getCRMDatabasePrefix(): string {
-    return str_replace('`', '', parent::getCRMDatabasePrefix());
+    $crmDatabaseName = parent::getCRMDatabaseName();
+    if (!empty($crmDatabaseName)) {
+      return "$crmDatabaseName.";
+    }
+    return $crmDatabaseName;
   }
 
   /**
@@ -1204,29 +1208,32 @@ AND    u.status = 1
    * @inheritdoc
    */
   public function theme(&$content, $print = FALSE, $maintenance = FALSE) {
-    $ret = FALSE;
+    if ($maintenance) {
+      \CRM_Core_Error::deprecatedWarning('CRM_Utils_System::theme called with $maintenance = TRUE - please use renderMaintenanceMessage instead');
+    }
 
     if (!$print) {
       if ($maintenance) {
-        backdrop_set_breadcrumb('');
-        backdrop_maintenance_theme();
-        if ($region = CRM_Core_Region::instance('html-header', FALSE)) {
-          CRM_Utils_System::addHTMLHead($region->render(''));
-        }
-        print theme('maintenance_page', ['content' => $content]);
+        print $this->renderMaintenanceMessage($content);
         exit();
       }
-      $ret = TRUE;
+      return $content;
     }
-    $out = $content;
 
-    if ($ret) {
-      return $out;
-    }
-    else {
-      print $out;
-      return NULL;
+    print $content;
+    return NULL;
+  }
+
+  /**
+   * @inheritdoc
+   */
+  public function renderMaintenanceMessage(string $content): string {
+    backdrop_set_breadcrumb('');
+    backdrop_maintenance_theme();
+    if ($region = CRM_Core_Region::instance('html-header', FALSE)) {
+      $this->addHTMLHead($region->render(''));
     }
+    return theme('maintenance_page', ['content' => $content]);
   }
 
   /**
