@@ -15,6 +15,8 @@
  * @copyright CiviCRM LLC https://civicrm.org/licensing
  */
 
+use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
+
 /**
  * Drupal specific stuff goes here.
  */
@@ -381,6 +383,7 @@ class CRM_Utils_System_Drupal8 extends CRM_Utils_System_DrupalBase {
    */
   public function permissionDenied() {
     \Drupal::service('civicrm.page_state')->setAccessDenied();
+    throw new AccessDeniedHttpException();
   }
 
   /**
@@ -952,12 +955,10 @@ class CRM_Utils_System_Drupal8 extends CRM_Utils_System_DrupalBase {
 
   /**
    * @inheritdoc
+   * @todo use Drupal "maintenance page" template and theme during installation
    */
-  public function theme(&$content, $print = FALSE, $maintenance = FALSE) {
-    // @todo use Drupal "maintenance page" template and theme during installation
-    // or upgrade.
-    print $content;
-    return NULL;
+  public function renderMaintenanceMessage(string $content): string {
+    return $content;
   }
 
   /**
@@ -1027,4 +1028,11 @@ class CRM_Utils_System_Drupal8 extends CRM_Utils_System_DrupalBase {
     }
   }
 
+  public function handleUnhandledException(\Throwable $e) {
+    if ($e instanceof AccessDeniedHttpException) {
+      throw $e;
+    }
+    CRM_Core_Error::handleUnhandledException($e);
+  }
+
 }
