@@ -274,6 +274,7 @@ class CRM_Utils_System_WordPress extends CRM_Utils_System_Base {
    * @inheritDoc
    */
   public function addHTMLHead($head) {
+    \CRM_Core_Error::deprecatedFunctionWarning("addHTMLHead is deprecated in WordPress and will be removed in a future version");
     static $registered = FALSE;
     if (!$registered) {
       // front-end view
@@ -938,13 +939,17 @@ class CRM_Utils_System_WordPress extends CRM_Utils_System_Base {
         $creds['user_password'] = $user_data['user_pass'];
         $creds['remember'] = TRUE;
 
-        // Authenticate and log the user in.
-        $user = wp_signon($creds, FALSE);
-        if (is_wp_error($user)) {
-          Civi::log()->error("Could not log the user in. WordPress returned: " . $user->get_error_message());
-        }
-        else {
-          $logged_in = TRUE;
+        $should_login_user = boolval(get_option('civicrm_automatically_sign_in_user', TRUE));
+        if (TRUE === $should_login_user) {
+          // Authenticate and log the user in.
+          $user = wp_signon($creds, FALSE);
+          if (is_wp_error($user)) {
+            Civi::log()
+              ->error("Could not log the user in. WordPress returned: " . $user->get_error_message());
+          }
+          else {
+            $logged_in = TRUE;
+          }
         }
       }
 
@@ -1212,7 +1217,7 @@ class CRM_Utils_System_WordPress extends CRM_Utils_System_Base {
     if (CRM_Core_Session::singleton()
       ->get('userID') == $contactID || CRM_Core_Permission::checkAnyPerm(['cms:administer users'])
     ) {
-      return CRM_Core_Config::singleton()->userFrameworkBaseURL . "wp-admin/user-edit.php?user_id=" . $uid;
+      return Civi::paths()->getVariable('wp.backend.base', 'url') . 'user-edit.php?user_id=' . $uid;
     }
   }
 
@@ -1681,8 +1686,12 @@ class CRM_Utils_System_WordPress extends CRM_Utils_System_Base {
 
   /**
    * @inheritdoc
+   * @todo why are the environment checks here? could they be removed
    */
   public function theme(&$content, $print = FALSE, $maintenance = FALSE) {
+    if ($maintenance) {
+      \CRM_Core_Error::deprecatedWarning('Calling CRM_Utils_Base::theme with $maintenance is deprecated - use renderMaintenanceMessage instead');
+    }
     if (!$print) {
       if (!function_exists('is_admin')) {
         throw new \Exception('Function "is_admin()" is missing, even though WordPress is the user framework.');
@@ -1702,6 +1711,28 @@ class CRM_Utils_System_WordPress extends CRM_Utils_System_Base {
     return NULL;
   }
 
+  /**
+   * @inheritdoc
+   * @todo environment checks are copied from the original implementation of `theme` above and should probably
+   * be removed
+   */
+  public function renderMaintenanceMessage(string $content): string {
+    if (!function_exists('is_admin')) {
+      throw new \Exception('Function "is_admin()" is missing, even though WordPress is the user framework.');
+    }
+    if (!defined('ABSPATH')) {
+      throw new \Exception('Constant "ABSPATH" is not defined, even though WordPress is the user framework.');
+    }
+    if (is_admin()) {
+      require_once ABSPATH . 'wp-admin/admin-header.php';
+    }
+    else {
+      // FIXME: we need to figure out to replace civicrm content on the frontend pages
+    }
+
+    return $content;
+  }
+
   /**
    * @inheritdoc
    */
