@@ -74,71 +74,6 @@ class CRM_Utils_Token {
     'welcome' => ['group'],
   ];
 
-  /**
-   * @deprecated
-   *   This is used by CiviMail but will be made redundant by FlexMailer.
-   * @return array
-   */
-  public static function getRequiredTokens() {
-    CRM_Core_Error::deprecatedFunctionWarning('token processor');
-    if (self::$_requiredTokens == NULL) {
-      self::$_requiredTokens = [
-        'domain.address' => ts("Domain address - displays your organization's postal address."),
-        'action.optOutUrl or action.unsubscribeUrl' => [
-          'action.optOut' => ts("'Opt out via email' - displays an email address for recipients to opt out of receiving emails from your organization."),
-          'action.optOutUrl' => ts("'Opt out via web page' - creates a link for recipients to click if they want to opt out of receiving emails from your organization. Alternatively, you can include the 'Opt out via email' token."),
-          'action.unsubscribe' => ts("'Unsubscribe via email' - displays an email address for recipients to unsubscribe from the specific mailing list used to send this message."),
-          'action.unsubscribeUrl' => ts("'Unsubscribe via web page' - creates a link for recipients to unsubscribe from the specific mailing list used to send this message. Alternatively, you can include the 'Unsubscribe via email' token or one of the Opt-out tokens."),
-        ],
-      ];
-    }
-    return self::$_requiredTokens;
-  }
-
-  /**
-   * Check a string (mailing body) for required tokens.
-   *
-   * @param string $str
-   *   The message.
-   *
-   * @return bool|array
-   *   true if all required tokens are found,
-   *    else an array of the missing tokens
-   *
-   * @deprecated since 5.78 will be removed around 5.90
-   */
-  public static function requiredTokens(&$str) {
-    CRM_Core_Error::deprecatedFunctionWarning('use flexmailer');
-    $requiredTokens = Civi\Core\Resolver::singleton()->call('call://civi_flexmailer_required_tokens/getRequiredTokens', []);
-
-    $missing = [];
-    foreach ($requiredTokens as $token => $value) {
-      if (!is_array($value)) {
-        if (!preg_match('/(^|[^\{])' . preg_quote('{' . $token . '}') . '/', $str)) {
-          $missing[$token] = $value;
-        }
-      }
-      else {
-        $present = FALSE;
-        $desc = NULL;
-        foreach ($value as $t => $d) {
-          $desc = $d;
-          if (preg_match('/(^|[^\{])' . preg_quote('{' . $t . '}') . '/', $str)) {
-            $present = TRUE;
-          }
-        }
-        if (!$present) {
-          $missing[$token] = $desc;
-        }
-      }
-    }
-
-    if (empty($missing)) {
-      return TRUE;
-    }
-    return $missing;
-  }
-
   /**
    * Wrapper for token matching.
    *
@@ -1005,134 +940,6 @@ class CRM_Utils_Token {
     return $returnProperties;
   }
 
-  /**
-   * Do not use this function.
-   *
-   * Gives required details of contacts in an indexed array format so we
-   * can iterate in a nice loop and do token evaluation
-   *
-   * @param array $contactIDs
-   * @param array $returnProperties
-   *   Of required properties.
-   * @param bool $skipOnHold Don't return on_hold contact info also.
-   *   Don't return on_hold contact info also.
-   * @param bool $skipDeceased Don't return deceased contact info.
-   *   Don't return deceased contact info.
-   * @param array $extraParams
-   *   Extra params - DEPRECATED
-   * @param array $tokens
-   *   The list of tokens we've extracted from the content.
-   * @param string|null $className
-   * @param int|null $jobID
-   *   The mailing list jobID - this is a legacy param.
-   *
-   * @deprecated
-   *
-   * @return array - e.g [[1 => ['first_name' => 'bob'...], 34 => ['first_name' => 'fred'...]]]
-   */
-  public static function getTokenDetails(
-    $contactIDs,
-    $returnProperties = NULL,
-    $skipOnHold = TRUE,
-    $skipDeceased = TRUE,
-    $extraParams = NULL,
-    $tokens = [],
-    $className = NULL,
-    $jobID = NULL
-  ) {
-    CRM_Core_Error::deprecatedFunctionWarning('If you hit this in mailing code you should use flexmailer - otherwise use the token processor');
-    $params = [];
-    foreach ($contactIDs as $contactID) {
-      $params[] = [
-        CRM_Core_Form::CB_PREFIX . $contactID,
-        '=',
-        1,
-        0,
-        0,
-      ];
-    }
-
-    // fix for CRM-2613
-    if ($skipDeceased) {
-      $params[] = ['is_deceased', '=', 0, 0, 0];
-    }
-
-    //fix for CRM-3798
-    if ($skipOnHold) {
-      $params[] = ['on_hold', '=', 0, 0, 0];
-    }
-
-    if ($extraParams) {
-      CRM_Core_Error::deprecatedWarning('Passing $extraParams to getTokenDetails() is not supported and will be removed in a future version');
-      $params = array_merge($params, $extraParams);
-    }
-
-    // if return properties are not passed then get all return properties
-    if (empty($returnProperties)) {
-      $fields = array_merge(array_keys(CRM_Contact_BAO_Contact::exportableFields()),
-        ['display_name', 'checksum', 'contact_id']
-      );
-      foreach ($fields as $val) {
-        // The unavailable fields are not available as tokens, do not have a one-2-one relationship
-        // with contacts and are expensive to resolve.
-        // @todo see CRM-17253 - there are some other fields (e.g note) that should be excluded
-        // and upstream calls to this should populate return properties.
-        $unavailableFields = ['group', 'tag'];
-        if (!in_array($val, $unavailableFields)) {
-          $returnProperties[$val] = 1;
-        }
-      }
-    }
-
-    $custom = [];
-    foreach ($returnProperties as $name => $dontCare) {
-      $cfID = CRM_Core_BAO_CustomField::getKeyID($name);
-      if ($cfID) {
-        $custom[] = $cfID;
-      }
-    }
-
-    [$contactDetails] = CRM_Contact_BAO_Query::apiQuery($params, $returnProperties, NULL, NULL, 0, count($contactIDs), TRUE, FALSE, TRUE, CRM_Contact_BAO_Query::MODE_CONTACTS, NULL, TRUE);
-
-    foreach ($contactIDs as $contactID) {
-      if (array_key_exists($contactID, $contactDetails)) {
-        if (!empty($contactDetails[$contactID]['preferred_communication_method'])
-        ) {
-          $communicationPreferences = [];
-          foreach ((array) $contactDetails[$contactID]['preferred_communication_method'] as $val) {
-            if ($val) {
-              $communicationPreferences[$val] = CRM_Core_PseudoConstant::getLabel('CRM_Contact_DAO_Contact', 'preferred_communication_method', $val);
-            }
-          }
-          $contactDetails[$contactID]['preferred_communication_method'] = implode(', ', $communicationPreferences);
-        }
-
-        foreach ($custom as $cfID) {
-          if (isset($contactDetails[$contactID]["custom_{$cfID}"])) {
-            $contactDetails[$contactID]["custom_{$cfID}"] = CRM_Core_BAO_CustomField::displayValue($contactDetails[$contactID]["custom_{$cfID}"], $cfID);
-          }
-        }
-
-        // special case for greeting replacement
-        foreach (['email_greeting', 'postal_greeting', 'addressee'] as $val) {
-          if (!empty($contactDetails[$contactID][$val])) {
-            $contactDetails[$contactID][$val] = $contactDetails[$contactID]["{$val}_display"];
-          }
-        }
-      }
-    }
-
-    // $contactDetails = &$details[0] = is an array of [ contactID => contactDetails ]
-    // also call a hook and get token details
-    CRM_Utils_Hook::tokenValues($contactDetails,
-      $contactIDs,
-      $jobID,
-      $tokens,
-      $className
-    );
-    return [$contactDetails];
-  }
-
   /**
    * Call hooks on tokens for anonymous users - contact id is set to 0 - this allows non-contact
    * specific tokens to be rendered
@@ -1262,8 +1069,11 @@ class CRM_Utils_Token {
    *
    * @return string
    *   The processed string
+   *
+   * @deprecated since 6.3 will be removed around 6.15
    */
-  public static function &replaceUserTokens($str, $knownTokens = NULL, $escapeSmarty = FALSE) {
+  public static function replaceUserTokens($str, $knownTokens = NULL, $escapeSmarty = FALSE) {
+    CRM_Core_Error::deprecatedFunctionWarning('no alternative');
     $key = 'user';
     if (!$knownTokens ||
       !isset($knownTokens[$key])
@@ -1289,6 +1099,7 @@ class CRM_Utils_Token {
    */
   public static function getUserTokenReplacement($token, $escapeSmarty = FALSE) {
     $value = '';
+    CRM_Core_Error::deprecatedFunctionWarning('no alternative');
 
     [$objectName, $objectValue] = explode('-', $token, 2);
 
@@ -1677,6 +1488,31 @@ class CRM_Utils_Token {
         'contribution_invoice_receipt' => [
           '$display_name' => 'contact.display_name',
           '$dataArray' => ts('see default template for how to show this'),
+          '$source' => 'contribution.source',
+          '$invoice_number' => 'contribution.invoice_number',
+          '$invoice_id' => 'contribution.invoice_id',
+          '$defaultCurrency' => 'contribution.currency',
+          '$amount' => 'contribution.total_amount',
+          '$amountDue' => 'contribution.balance_amount',
+          '$amountPaid' => 'contribution.paid_amount',
+          '$invoice_date' => 'contribution.receive_date',
+          '$refundedStatusId' => 'not available',
+          '$pendingStatusId' => 'not available',
+          '$cancelledStatusId' => 'not available',
+          '$contribution_status_id' => 'contribution.contribution_status_id',
+          '$contributionStatusName' => 'contribution.contribution_status_id:name',
+          '$subTotal' => 'contribution.tax_amount',
+          '$is_pay_later' => 'contribution.is_pay_later|bool',
+          '$domain_street_address' => 'domain.street_address',
+          '$domain_city' => 'domain.city',
+          '$domain_phone' => 'domain.phone',
+          '$domain_email' => 'domain.email',
+          '$domain_supplemental_address_1' => 'domain.supplemental_address_1',
+          '$domain_supplemental_address_2' => 'domain.supplemental_address_2',
+          '$domain_supplemental_address_3' => 'domain.supplemental_address_3',
+          '$domain_postal_code' => 'domain.postal_code',
+          '$domain_state' => 'domain.state_province_id:abbr',
+          '$domain_country' => 'domain.country_id:abbr',
         ],
         'contribution_online_receipt' => [
           '$contributeMode' => ts('no longer available / relevant'),
@@ -1703,6 +1539,7 @@ class CRM_Utils_Token {
           '$formValues' => 'use relevant token/s',
           '$module' => 'unknown',
           '$currency' => 'contribution.currency',
+          '$paidBy' => 'contribution.payment_instrument_id:label',
         ],
         'membership_online_receipt' => [
           '$dataArray' => ts('see default template for how to show this'),
@@ -1718,6 +1555,10 @@ class CRM_Utils_Token {
         'contribution_offline_receipt' => [
           '$totalTaxAmount' => 'contribution.tax_amount',
           '$getTaxDetails' => ts('no longer available / relevant'),
+          '$paidBy' => 'contribution.payment_instrument_id:label',
+          '$receive_date' => 'contribution.receive_date',
+          '$thankyou_date' => 'contribution.thankyou_date',
+          '$receipt_date' => 'contribution.receipt_date',
         ],
         'event_offline_receipt' => [
           '$contributeMode' => ts('no longer available / relevant'),
@@ -1748,9 +1589,13 @@ class CRM_Utils_Token {
           '`$participant.id`' => 'participant.id',
           '$dataArray' => ts('see default template for how to show this'),
           '$individual' => ts('see default template for how to show this'),
+          '$amount' => ts('see default template for how to show this'),
           '$location' => 'event.location',
+          '$register_date' => 'participant.register_date',
           '$participant.role' => 'participant.role_id:label',
           '$event.participant_role' => 'participant.role_id:label',
+          '$paidBy' => 'contribution.payment_instrument_id:label',
+          '$title' => 'event.title',
         ],
         'participant_transferred' => [
           '$location' => 'event.location',
@@ -1776,6 +1621,8 @@ class CRM_Utils_Token {
           '$location' => 'event.location',
           '$participant.role' => 'participant.role_id:label',
           '$event.participant_role' => 'participant.role_id:label',
+          '$contactDisplayName' => 'contact.display_name',
+          '$paymentsComplete' => 'contribution.balance_amount',
         ],
         'pledge_acknowledgement' => [
           '$domain' => ts('no longer available / relevant'),
