@@ -299,7 +299,7 @@ abstract class AbstractAction implements \ArrayAccess {
         $name = $property->getName();
         if ($name != 'version' && $name[0] != '_') {
           $docs = ReflectionUtils::getCodeDocs($property, 'Property', $vars);
-          $docs['default'] = $defaults[$name];
+          $docs['default'] = $defaults[$name] ?? NULL;
           // Exclude `null` which is not a value type
           if (!empty($docs['type']) && is_array($docs['type'])) {
             $docs['type'] = array_diff($docs['type'], ['null']);
@@ -478,6 +478,25 @@ abstract class AbstractAction implements \ArrayAccess {
     return $this->_reflection;
   }
 
+  /**
+   * @param array $savedRecords
+   * @param array|bool $select
+   * @return array
+   * @throws \CRM_Core_Exception
+   */
+  protected function reloadResults(array $savedRecords, mixed $select = TRUE): array {
+    $idField = CoreUtil::getIdFieldName($this->getEntityName());
+    /** @var AbstractGetAction $get */
+    $get = \Civi\API\Request::create($this->getEntityName(), 'get', ['version' => 4]);
+    $get
+      ->setCheckPermissions($this->getCheckPermissions())
+      ->addWhere($idField, 'IN', array_column($savedRecords, $idField));
+    if (is_array($select) && !empty($select)) {
+      $get->setSelect($select);
+    }
+    return (array) $get->execute();
+  }
+
   /**
    * Validates required fields for actions which create a new object.
    *
