@@ -110,6 +110,15 @@ abstract class Api4Query {
     return FALSE;
   }
 
+  protected function isDistinctUnion(): bool {
+    foreach ($this->api->getSets() as $set) {
+      if ($set[0] === 'UNION DISTINCT') {
+        return TRUE;
+      }
+    }
+    return FALSE;
+  }
+
   /**
    * Add LIMIT to query
    *
@@ -206,6 +215,54 @@ abstract class Api4Query {
         return 'NOT (' . $this->treeWalkClauses($clause[1], $type, $depth + 1) . ')';
 
       default:
+        if ($clause[1] === 'CONTAINS' || $clause[1] === 'NOT CONTAINS' || $clause[1] === 'CONTAINS ONE OF' || $clause[1] === 'NOT CONTAINS ONE OF') {
+          if ($clause[1] === 'CONTAINS ONE OF') {
+            $clause[1] = 'CONTAINS';
+            $binding = ' OR ';
+          }
+          elseif ($clause[1] === 'NOT CONTAINS ONE OF') {
+            $clause[1] = 'NOT CONTAINS';
+            $binding = ' OR ';
+          }
+          else {
+            $binding = ' AND ';
+          }
+
+          if (is_array($clause[2])) {
+            // Not should be applied to the entire clause instead of each piece
+            $not = '';
+            if (str_starts_with($clause[1], 'NOT')) {
+              $not = 'NOT';
+              $clause[1] = substr($clause[1], 4);
+            }
+            $queryString = '';
+
+            foreach ($clause[2] as $value) {
+              $subclauses = $clause;
+              // Strings must be quoted in ON clause
+              if ($type === 'ON' && is_string($value)) {
+                $value = "'$value'";
+              }
+
+              $subclauses[2] = $value;
+
+              if ($queryString !== '') {
+                $queryString .= $binding;
+              }
+
+              try {
+                $queryString .= $this->composeClause($subclauses, $type, $depth);
+              }
+              // Silently ignore fields the user lacks permission to see
+              catch (UnauthorizedException $e) {
+                return '';
+              }
+            }
+
+            return "$not($queryString)";
+          }
+        }
+
         try {
           return $this->composeClause($clause, $type, $depth);
         }
@@ -417,7 +474,7 @@ abstract class Api4Query {
       $operator = str_replace('EMPTY', 'NULL', $operator);
       // For strings & numbers, create an OR grouping of empty value OR null
       if (in_array($field['data_type'] ?? NULL, ['String', 'Integer', 'Float', 'Boolean'], TRUE)) {
-        $emptyVal = $field['data_type'] === 'String' ? '""' : '0';
+        $emptyVal = ($field['data_type'] === 'String' || $field['serialize']) ? '""' : '0';
         $isEmptyClause = $operator === 'IS NULL' ? "= $emptyVal OR" : "<> $emptyVal AND";
         return "($fieldAlias $isEmptyClause $fieldAlias $operator)";
       }
