@@ -69,6 +69,15 @@ abstract class AbstractProcessor extends \Civi\Api4\Generic\AbstractAction {
 
   protected $_entityValues = [];
 
+  protected array $_response = [];
+
+  /**
+   * Line items gathered from entities on the form - for payment processing
+   *
+   * @var array[]
+   */
+  protected array $_lineItems = [];
+
   /**
    * @param \Civi\Api4\Generic\Result $result
    * @throws \CRM_Core_Exception
@@ -85,8 +94,25 @@ abstract class AbstractProcessor extends \Civi\Api4\Generic\AbstractAction {
     if (empty($this->_afform['submit_currently_open'])) {
       throw new UnauthorizedException(E::ts('This form is not currently open for submissions.'), ['show_detailed_error' => TRUE]);
     }
+
+    // Set args based on extra data in authx bearer token. E.g. a link to the form could contain a case id when the link
+    // is send by email from the manage case screen.
+    $session = \CRM_Core_Session::singleton();
+    $authx = $session->get('authx');
+    if ($authx && isset($authx['jwt']['afformArgs'])) {
+      // It could be that afformArgs is stdClass
+      // so this way we convert it to an array.
+      $afformOptions = json_decode(json_encode($authx['jwt']['afformArgs']), TRUE);
+      if (is_array($afformOptions)) {
+        foreach ($afformOptions as $afformOption => $afformOptionValue) {
+          $this->args[$afformOption] = $afformOptionValue;
+        }
+      }
+    }
+
     $this->_formDataModel = new FormDataModel($this->_afform['layout']);
     $this->loadEntities();
+    // TODO: use _response more consistently
     $result->exchangeArray($this->processForm());
   }
 
@@ -142,6 +168,17 @@ abstract class AbstractProcessor extends \Civi\Api4\Generic\AbstractAction {
     }
   }
 
+  /**
+   * Unload a certain entity.
+   *
+   * @param array $entity
+   * @return void
+   */
+  public function unloadEntity(array $entity) {
+    unset($this->_entityIds[$entity['name']]);
+    unset($this->_entityValues[$entity['name']]);
+  }
+
   /**
    * Fetch all data needed to display a given entity on this form
    *
@@ -172,11 +209,7 @@ abstract class AbstractProcessor extends \Civi\Api4\Generic\AbstractAction {
     // Limit number of records based on af-repeat settings
     // If 'min' is set then it is repeatable, and max will either be a number or NULL for unlimited.
     if (isset($entity['min']) && isset($entity['max'])) {
-      foreach (array_keys($values) as $count => $index) {
-        if ($count >= $entity['max']) {
-          unset($values[$index]);
-        }
-      }
+      $values = array_slice($values, 0, $entity['max'], TRUE);
     }
     $matchField = self::getNestedKey($values);
     if (!$matchField) {
@@ -731,6 +764,36 @@ abstract class AbstractProcessor extends \Civi\Api4\Generic\AbstractAction {
     return is_array($firstValue) && $firstValue ? array_keys($firstValue)[0] : NULL;
   }
 
+  /**
+   * Set a key in the api response
+   *
+   * Note: key should be recognised by the afForm controller
+   * expected keys are:
+   *   token, redirect, message
+   *
+   * @param string $key
+   * @param mixed $value
+   */
+  public function setResponseItem(string $key, $value): void {
+    $this->_response[$key] = $value;
+  }
+
+  /**
+   * Retrieve stashed line items
+   * @return array
+   */
+  public function getLineItems(): array {
+    return $this->_lineItems;
+  }
+
+  /**
+   * Stash line items from across form entities
+   * @param array $lineItem
+   */
+  public function addLineItem(array $lineItem): void {
+    $this->_lineItems[] = $lineItem;
+  }
+
   /**
    * Function to get allowed action of a join entity
    *
@@ -748,4 +811,32 @@ abstract class AbstractProcessor extends \Civi\Api4\Generic\AbstractAction {
     return $actions;
   }
 
+  /**
+   * Function to replace tokens with entity values in e.g. redirect urls
+   *
+   * Tokens look like [Participant1.0.id]
+   *
+   * @param string $text
+   *
+   * @return string
+   */
+  public function replaceTokens(string $text): string {
+    $matches = [];
+    preg_match_all('/\[[a-zA-Z0-9]{1,}\.[0-9]{1,}\.[^.]{1,}\]/', $text, $matches);
+
+    foreach ($matches[0] as $match) {
+      // strip [ ] and split on .
+      [$entityName, $index, $field] = explode('.', substr($match, 1, -1));
+      if ($field === 'id') {
+        $value = $this->_entityIds[$entityName][$index]['id'];
+      }
+      else {
+        $value = $this->_entityValues[$entityName][$index]['fields'][$field];
+      }
+      $text = str_replace($match, $value, $text);
+    }
+
+    return $text;
+  }
+
 }
