@@ -89,8 +89,10 @@ class Admin {
       '<' => '<',
       '>=' => '≥',
       '<=' => '≤',
-      'CONTAINS' => E::ts('Contains'),
-      'NOT CONTAINS' => E::ts("Doesn't Contain"),
+      'CONTAINS' => E::ts('Contains All'),
+      'NOT CONTAINS' => E::ts("Doesn't Contain All"),
+      'CONTAINS ONE OF' => E::ts('Contains Any'),
+      'NOT CONTAINS ONE OF' => E::ts("Doesn't Contain Any"),
       'IN' => E::ts('Is One Of'),
       'NOT IN' => E::ts('Not One Of'),
       'LIKE' => E::ts('Is Like'),
@@ -103,6 +105,7 @@ class Admin {
       'NOT BETWEEN' => E::ts('Not Between'),
       'IS EMPTY' => E::ts('Is Empty'),
       'IS NOT EMPTY' => E::ts('Not Empty'),
+      'IS NOT NULL' => E::ts('Any value'),
     ];
   }
 
@@ -202,7 +205,10 @@ class Admin {
       $possibleColumns[$column] = "$column:label";
     }
     // Other possible relevant columns... now we're just guessing
-    $possibleColumns['financial_type_id'] = 'financial_type_id:label';
+    //
+    // TODO: these can be specified using the @searchColumns annotation on
+    // the Api4 entity class so would probably be better to specify sensible
+    // options for core entities explicitly - which allows you to order logically too
     $possibleColumns['description'] = 'description';
     // E.g. "activity_status_id"
     $possibleColumns[strtolower($entity['name']) . 'status_id'] = strtolower($entity['name']) . 'status_id:label';
